==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-mainmenu/mainmenu_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="245"/>
        <source>Show/hide main menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leave</source>
        <translation type="vanished">Полишити</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <source>LXQt Main Menu settings</source>
        <translation type="vanished">Налаштування головного меню LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation type="vanished">Показувати текст</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation type="vanished">Текст кнопки</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Button text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="52"/>
        <source>Custom font size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="62"/>
        <source> pt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="81"/>
        <source>Menu file</source>
        <translation>Файл меню</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="87"/>
        <source>Menu file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="101"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Keyboard Shortcut</source>
        <translation>Клавіатурне скорочення</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="130"/>
        <source>Click the button to record shortcut:</source>
        <translation>Натисніть кнопку, щоб змінити клавіатурне скорочення:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="55"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="100"/>
        <source>Choose menu file</source>
        <translation>Оберіть файл меню</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="100"/>
        <source>Menu files (*.menu)</source>
        <translation>Файли меню (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-panel/plugin-mainmenu/mainmenu_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="95"/>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="101"/>
        <source>Show/hide main menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leave</source>
        <translation type="vanished">Полишити</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <source>LXQt Main Menu settings</source>
        <translation type="vanished">Налаштування головного меню LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation type="vanished">Показувати текст</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation type="vanished">Текст кнопки</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Файл меню</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="175"/>
        <source>max. item width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="182"/>
        <source>Show matching entries:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="196"/>
        <source>Maximum visible items:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="203"/>
        <source>Filter menu entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="223"/>
        <source>Hide menu entries while searching</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Клавіатурне скорочення</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Натисніть кнопку, щоб змінити клавіатурне скорочення:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="156"/>
        <source>Choose icon file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="158"/>
        <source>Images (*.svg *.png)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="170"/>
        <source>Choose menu file</source>
        <translation>Оберіть файл меню</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="172"/>
        <source>Menu files (*.menu)</source>
        <translation>Файли меню (*.menu)</translation>
    </message>
</context>
</TS>
